@@ -200,6 +200,7 @@ async def update_or_create_redis_instance_from_django_instance(
         redis_root,
         get_or_create_redis_model_from_django_model
 ):
+    print(django_instance.id)
     redis_instance = redis_root.get(redis_model, django_id=django_instance.id)
     redis_dict = await django_instance_to_redis_params(
         django_instance,
@@ -213,14 +214,18 @@ async def update_or_create_redis_instance_from_django_instance(
             django_id=django_instance.id,
             **redis_dict
         ).save()
+        print(f'{redis_model} with django_id={django_instance.id} created...')
+        result_redis_instance = redis_root.get(redis_model, django_id=django_instance.id)[0]
     else:
         redis_instance = redis_instance[0]
         redis_root.update(redis_model, redis_instance,
                           django_id=django_instance.id,
                           **redis_dict
                           )
+        result_redis_instance = redis_instance
+        print(f'{redis_model} with django_id={django_instance.id} existing...')
+
 
-    result_redis_instance = redis_root.get(redis_model, django_id=django_instance.id)[0]
     return result_redis_instance
 
 
